@@ -48,6 +48,7 @@
 #include "localisation.h"
 #include "settings.h"
 #include "filters.h"
+#include "he-about-dialog.h"
 
 #define CSD_CALL_BUS_NAME	"com.nokia.csd.Call"
 #define CSD_CALL_INTERFACE	"com.nokia.csd.Call"
@@ -229,9 +230,43 @@ static void delete_record(GtkButton* button, gpointer data)
 	}
 
 	rtcom_el_delete_event(el, id, NULL);
+	GtkWidget *banner = hildon_banner_show_information(NULL, NULL,
+							"Call Deleted from Call Log");
 
 }
 
+static void show_contact(GtkButton* button, gpointer data)
+{
+	/*
+	 * I'd prefer to have the contact come up in a dialog popup but for some reason
+	 * the below code doesn't display the dialog properly.
+	GtkWidget *dialog;
+    OssoABookContact *contact = data;
+    GtkWidget *starter;
+    starter = GTK_WIDGET(osso_abook_touch_contact_starter_new_with_contact(NULL, contact));
+    dialog = GTK_WIDGET(osso_abook_touch_contact_starter_dialog_new(NULL, starter));
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(GTK_WIDGET(dialog));
+    */
+
+    GtkWidget *starter, *window;
+    OssoABookContact *contact = data;
+    starter = osso_abook_touch_contact_starter_new_with_contact(NULL, contact);
+    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_container_add (GTK_CONTAINER (window), starter);
+
+    gtk_widget_show (starter);
+    gtk_widget_show (window);
+
+}
+
+static void delete_button_clicked (GtkButton* button, gpointer data)
+{
+	g_print("button clicked\n");
+	GtkWidget *detailsWindow = GTK_WIDGET(data);
+	gtk_widget_destroy(detailsWindow);
+
+}
 
 void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
     GtkTreeViewColumn *column, gpointer user_data)
@@ -246,12 +281,11 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
 	GtkWidget * local_box;
 	GtkWidget * button_box;
 
-	GtkWidget * timestamp_label;
+	GtkWidget * timestamp_label, *end_timestamp_label;
 	GtkWidget * icon_widget, * remote_details;
 	GtkWidget * service_icon_widget, * local_details;
 	GtkWidget * delete_button, * call_button, * contact_button;
 
-
 	/* Get the information we want to display from the model.
 	 *
 	 */
@@ -263,6 +297,7 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
     gchar *remote_account;
     gchar *text;
     gint timestamp;
+    gint end_timestamp;
     gint count;
     gchar *group_uid;
     gchar *group_title;
@@ -274,6 +309,7 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
     const gchar *title_col = NULL;
     const gchar *name_str = NULL;
     gchar time_str[256];
+    gchar end_time_str[256];
 
     GtkTreeIter iter;
     RTComLogModel *model = gtk_tree_view_get_model(tree_view);
@@ -285,6 +321,7 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
               RTCOM_LOG_VIEW_COL_REMOTE_NAME, &remote_name,
               RTCOM_LOG_VIEW_COL_REMOTE_ACCOUNT, &remote_uid,
               RTCOM_LOG_VIEW_COL_TIMESTAMP, &timestamp,
+              RTCOM_LOG_VIEW_COL_END_TIMESTAMP, &end_timestamp,
               RTCOM_LOG_VIEW_COL_COUNT, &count,
               RTCOM_LOG_VIEW_COL_GROUP_UID, &group_uid,
               RTCOM_LOG_VIEW_COL_GROUP_TITLE, &group_title,
@@ -300,14 +337,21 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
     get_time_string (time_str, 256, timestamp);
     g_debug("time : %s",  time_str);
 
-	g_debug("remote_name %s", remote_name);
-    g_debug("remote_account %s", remote_account);
-    g_debug("local_account %s", local_account);
-    g_debug("remote_uid %s", remote_uid);
+    if(end_timestamp != 0)
+    {
+    	get_time_string (end_time_str, 256, end_timestamp);
+    	g_debug("end_time : %s",  end_time_str);
+    }
+
+	g_printf("remote_name %s ", remote_name);
+    g_printf("remote_account %s ", remote_account);
+    g_printf("local_account %s ", local_account);
+    g_printf("remote_uid %s ", remote_uid);
+    g_printf("end_timestamp %d", end_timestamp);
     g_debug("group_uid %s", group_uid);
     g_debug("group_title %s", group_title);
-    g_debug("service %s", service);
-    g_debug("event_type %s", event_type);
+    g_printf("service %s", service);
+    g_printf("event_type %s", event_type);
     g_debug("count %d", count);
     g_debug("text %s", text);
     g_debug("event_id %d", event_id);
@@ -327,22 +371,59 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
 
 	icon_widget = gtk_image_new_from_pixbuf(icon);
 	timestamp_label = gtk_label_new (time_str);
+
 	gtk_box_pack_start(GTK_BOX(timestamp_box), icon_widget, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(timestamp_box), timestamp_label, FALSE, FALSE, 0);
+	if(end_timestamp != 0)
+	{
+		gint length = end_timestamp - timestamp;
+		if(length > 0)
+		{
+			gint minutes = length / 60;
+			gint seconds = length - (minutes * 60);
+
+			gchar *length_str;
+			if(length < 60)
+				length_str = g_strdup_printf(" for 0m %ds", length);
+			else
+				length_str = g_strdup_printf(" for %dm %ds", minutes, seconds);
+
+			end_timestamp_label = gtk_label_new(length_str);
+			gtk_box_pack_start(GTK_BOX(timestamp_box), end_timestamp_label, FALSE, FALSE, 0);
+			if(length_str != NULL)
+				g_free (length_str);
+		}
+	}
 
 
 	service_icon_widget = gtk_image_new_from_pixbuf(service_icon);
-	gchar * remote_str = g_strdup_printf("%s (%s)", remote_name, remote_account);
+
+	gchar * remote_str;
+	gboolean is_contact = FALSE;
+	if(remote_name == NULL || (*remote_name == '\0'))
+	{
+		g_printf("remote_name is null\n");
+		if(remote_uid == NULL || (*remote_uid == '\0'))
+			remote_str = g_strdup_printf("Unknown Number");
+		else
+			remote_str = g_strdup_printf("%s", remote_account);
+	}
+	else
+	{
+		g_printf("remote_name is not null\n");
+		is_contact = TRUE;
+		remote_str = g_strdup_printf("%s (%s)", remote_name, remote_account);
+	}
+
 	remote_details = gtk_label_new (remote_str);
 	gtk_box_pack_start(GTK_BOX(remote_box), service_icon_widget, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(remote_box), remote_details, FALSE, FALSE, 0);
-	g_free(remote_str);
 
 	gchar * local_str = g_strdup_printf("Account : (%s)", local_account);
 	local_details = gtk_label_new (local_str);
 	gtk_box_pack_start(GTK_BOX(local_box), local_details, FALSE, FALSE, 0);
 
-
+	gtk_box_set_spacing(GTK_BOX(button_box), 10);
 	delete_button = gtk_button_new_with_label("Delete");
 	hildon_gtk_widget_set_theme_size(delete_button, HILDON_SIZE_FINGER_HEIGHT);
 	g_signal_connect(
@@ -350,28 +431,42 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
 	          "clicked",
 	          G_CALLBACK(delete_record),
 	          event_id);
+	g_signal_connect(
+		          G_OBJECT(delete_button),
+		          "clicked",
+		          G_CALLBACK(delete_button_clicked),
+		          detailsWindow);
 	gtk_box_pack_start(GTK_BOX(button_box), delete_button, FALSE, FALSE, 0);
 	gtk_widget_show(delete_button);
 
-	/*call_button = gtk_button_new_with_label(" Call ");
-	hildon_gtk_widget_set_theme_size(call_button, HILDON_SIZE_FINGER_HEIGHT);
-	g_signal_connect(
-	          G_OBJECT(call_button),
-	          "clicked",
-	          G_CALLBACK(make_call),
-	          remote_account);
+	if(strcmp(local_account, "ring/tel/ring") == 0 && (*remote_account != '\0'))
+	{
+		call_button = gtk_button_new_with_label(" Call Number ");
 
-	gtk_box_pack_start(GTK_BOX(button_box), call_button, FALSE, FALSE, 0);
-	gtk_widget_show(call_button);*/
+		hildon_gtk_widget_set_theme_size(call_button, HILDON_SIZE_FINGER_HEIGHT);
+		g_signal_connect(
+				G_OBJECT(call_button),
+				"clicked",
+				G_CALLBACK(make_call),
+				remote_account);
 
-	contact_button = gtk_button_new_with_label("Contact");
-	/*g_signal_connect(
-	          G_OBJECT(all_button),
-	          "clicked",
-	          G_CALLBACK(delete_record),
-	          event_id);*/
-	/*gtk_box_pack_start(GTK_BOX(button_box), contact_button, FALSE, FALSE, 0);
-	gtk_widget_show(contact_button);*/
+		gtk_box_pack_start(GTK_BOX(button_box), call_button, FALSE, FALSE, 0);
+		gtk_widget_show(call_button);
+	}
+
+	/*only display contact button if it's a contact*/
+	if(contact != NULL)
+	{
+		contact_button = gtk_button_new_with_label("Open Contact Card");
+		g_signal_connect(
+				  G_OBJECT(contact_button),
+				  "clicked",
+				  G_CALLBACK(show_contact),
+				  contact);
+		gtk_box_pack_start(GTK_BOX(button_box), contact_button, FALSE, FALSE, 0);
+		gtk_widget_show(contact_button);
+
+	}
 
 	gtk_box_pack_start(GTK_BOX(main_box), timestamp_box, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(main_box), remote_box, FALSE, FALSE, 0);
@@ -385,7 +480,6 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
     hildon_program_add_window(data->program, HILDON_WINDOW(detailsWindow));
     gtk_widget_show_all (GTK_WIDGET(detailsWindow));
 
-
 	g_free (text);
 	g_free (remote_name);
 	g_free (remote_uid);
@@ -393,6 +487,10 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
 	g_free (group_title);
 	g_free (service);
 	g_free (event_type);
+	g_free (local_str);
+	if(remote_str != NULL)
+		g_free (remote_str);
+
 
 
 	if (contact != NULL)
@@ -401,9 +499,25 @@ void row_activated(GtkTreeView *tree_view, GtkTreePath *path,
 	data->showing_details = FALSE;
 }
 
-static void button_clicked (GtkButton* button, gpointer data)
+void row_tapped(GtkTreeView *tree_view, GtkTreePath *path, gpointer user_data)
 {
-    gtk_main_quit();
+	row_activated(tree_view, path, NULL, user_data);
+}
+
+static void aboutButton_clicked (GtkButton* button, gpointer data)
+{
+	AppData * appdata = data;
+	he_about_dialog_present(GTK_WINDOW(appdata->mainWindow),
+	                        "Extended Call Log",
+	                        NULL,
+	                        APP_VER,
+	                        "View your complete call history",
+	                        "(c) 2010 Thom Troy",
+	                        "http://extcalllog.garage.maemo.org",
+	                        "https://bugs.maemo.org/enter_bug.cgi?product=Extended%20Call%20Log",
+	                        "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=3S5DWH4C95UG8");
+
+
 }
 
 static void toggle_date_filter (GtkButton* button, gpointer data)
@@ -976,6 +1090,7 @@ int main( int argc, char* argv[] )
     GtkWidget * call_type_button = NULL;
     GtkWidget * date_button = NULL;
     GtkWidget * settings_button = NULL;
+    GtkWidget * about_button = NULL;
     HildonAppMenu *menu;
 
     GtkWidget * scrolled_window = NULL;
@@ -1139,6 +1254,15 @@ int main( int argc, char* argv[] )
     hildon_app_menu_append (menu, GTK_BUTTON (date_button));
     gtk_widget_show(date_button);
 
+    about_button = gtk_button_new_with_label("About");
+    g_signal_connect(
+             G_OBJECT(about_button),
+             "clicked",
+              G_CALLBACK(aboutButton_clicked),
+              &appdata);
+    hildon_app_menu_append (menu, GTK_BUTTON (about_button));
+    gtk_widget_show(about_button);
+
     gtk_widget_show_all (GTK_WIDGET (menu));
     hildon_window_set_app_menu (HILDON_WINDOW (appdata.mainWindow), menu);
 
@@ -1156,8 +1280,11 @@ int main( int argc, char* argv[] )
                 GTK_CONTAINER(appdata.mainWindow),
                 box);
 
-    g_signal_connect(G_OBJECT(appdata.log_view), "row-activated",
-    		G_CALLBACK(row_activated), &appdata);
+    /*g_signal_connect(G_OBJECT(appdata.log_view), "row-activated",
+    		G_CALLBACK(row_activated), &appdata);*/
+
+    g_signal_connect(G_OBJECT(appdata.log_view), "hildon-row-tapped",
+       		G_CALLBACK(row_tapped), &appdata);
 
 
     /* Quit program when window is closed. */
